@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::duration::str_alami_en;
 
-our $DATE = '2016-06-30'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2018-06-04'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,9 +9,9 @@ use warnings;
 
 sub meta {
     +{
-        v => 2,
+        v => 3,
         enable_by_default => 0,
-        might_die => 1,
+        might_fail => 1,
         prio => 60, # a bit lower than normal
         precludes => [qr/\Astr_alami(_.+)?\z/, 'str_human'],
     };
@@ -29,11 +29,11 @@ sub coerce {
     $res->{modules}{"DateTime::Format::Alami::EN"} //= 0;
     $res->{expr_coerce} = join(
         "",
-        "do { my \$res = DateTime::Format::Alami::EN->new->parse_datetime_duration($dt, {format=>'combined'}) or die \"Can't coerce string '\".$dt.\"' to duration\"; ",
-        ($coerce_to eq 'float(secs)' ? "\$res = \$res->{seconds}; " :
-             $coerce_to eq 'DateTime::Duration' ? "\$res = \$res->{Duration}; " :
+        "do { my \$res; eval { \$res = DateTime::Format::Alami::EN->new->parse_datetime_duration($dt, {format=>'combined'}) }; ",
+        ($coerce_to eq 'float(secs)' ? "if (\$@) { ['Invalid duration syntax'] } else { [undef, \$res->{seconds}] } " :
+             $coerce_to eq 'DateTime::Duration' ? "if (\$@) { ['Invalid duration syntax'] } else { [undef, \$res->{Duration}] } " :
              (die "BUG: Unknown coerce_to '$coerce_to'")),
-        "\$res }",
+        "}",
     );
     $res;
 }
@@ -53,7 +53,7 @@ Data::Sah::Coerce::perl::duration::str_alami_en - Coerce duration from string pa
 
 =head1 VERSION
 
-This document describes version 0.002 of Data::Sah::Coerce::perl::duration::str_alami_en (from Perl distribution Data-Sah-Coerce-perl-duration-str_alami_en), released on 2016-06-30.
+This document describes version 0.003 of Data::Sah::Coerce::perl::duration::str_alami_en (from Perl distribution Data-Sah-Coerce-perl-duration-str_alami_en), released on 2018-06-04.
 
 =head1 DESCRIPTION
 
@@ -85,7 +85,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
